searchData={"items":[{"type":"module","title":"keysmith","doc":"Library for generating unique IDs.\n\nKeySmith is a library for generating unique IDs. It supports two types of\nIDs:\n\n* UUID ([RFC-9562](https://www.rfc-editor.org/rfc/rfc9562.html))\n    * Version 4\n    * Version 7\n* TypeID ([specification](https://github.com/jetify-com/typeid/tree/main/spec))\n    * TypeID's embed a UUID v7 by default, but can be customized with any\n      supported UUID version.","ref":"keysmith.html"},{"type":"function","title":"keysmith.parse/2","doc":"Parse an ID into its components.\n\nFormat can be one of `uuid` or `type_id` ([`id_type()`](#id_type/0)).\n\n* `uuid`\n\n  UUID will get decoded automatically based on their encoded type. The supported\n  types are listed in the [`uuid/2`](#uuid/2) documentation. Only the full\n  format of the UUID tuples can be returned by this function.","ref":"keysmith.html#parse/2"},{"type":"function","title":"Example - keysmith.parse/2","doc":"```erlang\n  1> UUIDv7 = keysmith:uuid({v7, 123}).\n  <<\"00000000-007b-7054-9789-64298c4136ee\">>\n  2> keysmith:parse(uuid, UUIDv7).\n  {v7,123,<<5,4:4>>,<<94,37,144,166,49,4,219,46:6>>}\n  ```\n\n* `type_id`\n\n  A TypeID will get decoded to a tuple of the type and the UUID format. The type\n  **must** exist as atom for this fuction to return succesfully (it uses\n  [`binary_to_existing_atom/1`](https://www.erlang.org/doc/apps/erts/erlang.html#binary_to_existing_atom/1)\n  internally).\n\n  The UUID suffix format must be in lowercase Crockfords's base32 encoding,\n  otherwise an error will be thrown.","ref":"keysmith.html#parse/2-example"},{"type":"function","title":"Example - keysmith.parse/2","doc":"```erlang\n  1> TypeID = keysmith:type_id(my_type).\n  <<\"my_type_01j8m75gy0fqws0860vmrqv1rr\">>\n  2> keysmith:parse(type_id, TypeID).\n  {my_type,{v7,1727255462848,\n               <<223,9:4>>,\n               <<64,131,3,116,197,246,28,24:6>>}}\n  ```","ref":"keysmith.html#parse/2-example"},{"type":"function","title":"Errors - keysmith.parse/2","doc":"This fuction raises the following exceptions:\n\n* `{invalid_id, type_id, ID}` if a TypeID is parsed and is not a valid TypeID:\n    * The type is not decodable into an existing atom\n    * The UUID suffix not being a 26-byte lowercase Crockfords's base32\n      string\n* `{invalid_id, uuid, ID}` if a UUID is parsed and the ID is not a valid UUID,\n  or if a TypeID contains a UUID suffix that is not a valid UUID:\n    * The UUID not being a valid hexadecimal 36-byte UUID (with dashes)\n    * The UUID not being a valid hexadecimal 32-byte UUID (without dashes)\n    * The UUID not being a raw binary UUID of 128 bits\n* `{invalid_id_type, Type}` if the format is not supported.","ref":"keysmith.html#parse/2-errors"},{"type":"function","title":"keysmith.type_id/1","doc":"Create a TypeID for the specified type prefix.\n\nThis creates a TypeID with the specified type prefix and a UUID version 7 suffix\nincluding the current Unix system time in milliseconds.","ref":"keysmith.html#type_id/1"},{"type":"function","title":"Example - keysmith.type_id/1","doc":"```erlang\n1> keysmith:type_id(my_type).\n<<\"my_type_01j8j55ywkesavxf5avszv4jv1\">>\n```\n\nEquivalent to [`type_id(Type, v7)`](#type-id/2).","ref":"keysmith.html#type_id/1-example"},{"type":"function","title":"keysmith.type_id/2","doc":"Generate a type ID for the specified type and UUID format. The UUID format can\nbe any format supported by [`uuid/2`](#uuid/2).\n\nTypeIDs are encoded with a lowercase version of Crockford's base32 encoding.","ref":"keysmith.html#type_id/2"},{"type":"function","title":"Example - keysmith.type_id/2","doc":"```erlang\n1> keysmith:type_id(my_type, {v4, <<0:48>>, <<0:12>>, <<0:62>>}).\n<<\"my_type_00000000008008000000000000\">>\n```","ref":"keysmith.html#type_id/2-example"},{"type":"function","title":"keysmith.uuid/1","doc":"","ref":"keysmith.html#uuid/1"},{"type":"function","title":"keysmith.uuid/2","doc":"Generate a UUID in the specified format.\n\nThe following types are supported:\n* `v4` - Random UUID v4.\n* `{v4, RandA, RandB, RandC}` - UUID v4 with set random parts.\n* `v7` - UUID v7 with the current system timestamp and a random component.\n* `{v7, TS}` - UUID v7 with a set timestamp and a random component.\n* `{v7, TS, RandB, RandC}` - UUID v7 with a set timestamp and set random components.\n\nThe following formats are supported:\n* `bytes` / `binary` - UUID as a raw 16 byte (128 bit) binary.\n* `hex` - UUID as a hexadecimal lowercase string with dashes.\n* `hex_nodash` - UUID as a hexadecimal lowercise string without dashes.\n\nIf custom random parts are provided, they must be bitstrings of exactly 48, 12,\nand 62 bits respectively (for example assuming each variable contains an\ninteger, the binary syntax would be `< >`, `< >`, and\n`< >`).","ref":"keysmith.html#uuid/2"},{"type":"function","title":"Errors - keysmith.uuid/2","doc":"This fuction raises the following exceptions:\n\n* `error:{invalid_uuid_spec, Spec}` when an unsupported or invalid specification\n  is specified.\n* `error:{invalid_uuid_format, Format}` when an unsupported or invalid format is\n  specified.","ref":"keysmith.html#uuid/2-errors"},{"type":"function","title":"Example - keysmith.uuid/2","doc":"```erlang\n1> keysmith:uuid(v4).\n<<\"38f18026-c2ee-4b5b-a8f7-439c33fb2a7a\">>\n2> keysmith:uuid(v7).\n<<\"019228d7-b720-7484-ab83-25332e9b0a33\">>\n```","ref":"keysmith.html#uuid/2-example"},{"type":"type","title":"keysmith.id/0","doc":"An atom representing the type of ID","ref":"keysmith.html#t:id/0"},{"type":"type","title":"keysmith.type_id/0","doc":"A generated TypeID","ref":"keysmith.html#t:type_id/0"},{"type":"type","title":"keysmith.type_id_prefix/0","doc":"A TypeID 'type' prefix","ref":"keysmith.html#t:type_id_prefix/0"},{"type":"type","title":"keysmith.type_id_spec/0","doc":"An Erlang representation of a TypeID","ref":"keysmith.html#t:type_id_spec/0"},{"type":"type","title":"keysmith.uuid/0","doc":"A generated UUID value","ref":"keysmith.html#t:uuid/0"},{"type":"type","title":"keysmith.uuid_binary/0","doc":"UUID in raw binary format","ref":"keysmith.html#t:uuid_binary/0"},{"type":"type","title":"keysmith.uuid_format/0","doc":"UUID output format","ref":"keysmith.html#t:uuid_format/0"},{"type":"type","title":"keysmith.uuid_hex/0","doc":"UUID in hex format with dashes","ref":"keysmith.html#t:uuid_hex/0"},{"type":"type","title":"keysmith.uuid_hex_nodash/0","doc":"UUID in hex format without dashes","ref":"keysmith.html#t:uuid_hex_nodash/0"},{"type":"type","title":"keysmith.uuid_rand_a/0","doc":"A 48-bit random bitstring used in UUID generation","ref":"keysmith.html#t:uuid_rand_a/0"},{"type":"type","title":"keysmith.uuid_rand_b/0","doc":"A 12-bit random bitstring used in UUID generation","ref":"keysmith.html#t:uuid_rand_b/0"},{"type":"type","title":"keysmith.uuid_rand_c/0","doc":"A 62-bit random bitstring used in UUID generation","ref":"keysmith.html#t:uuid_rand_c/0"},{"type":"type","title":"keysmith.uuid_spec/0","doc":"An Erlang representation of a UUID","ref":"keysmith.html#t:uuid_spec/0"},{"type":"type","title":"keysmith.uuid_v4/0","doc":"UUID version 4 (with optional random components)","ref":"keysmith.html#t:uuid_v4/0"},{"type":"type","title":"keysmith.uuid_v7/0","doc":"UUID version 7 (with optional timestamp and random components)","ref":"keysmith.html#t:uuid_v7/0"},{"type":"type","title":"keysmith.uuid_v7_unix_ts_ms/0","doc":"UNIX timestamp in millisecond resolution.\n\nTimestamp value as generated from\n[`erlang:system_time(millisecond)`](https://www.erlang.org/doc/apps/erts/erlang.html#system_time/1).","ref":"keysmith.html#t:uuid_v7_unix_ts_ms/0"},{"type":"extras","title":"Overview","doc":"# keysmith [![Erlang CI][ci-img]][ci]\n\nKeysmith is a well tested and performant library for generating unique\nidentifiers. Keysmith currently supports the following formats:\n\n* UUID\n  * Version 4 (random)\n  * Version 7 (time-based)\n* TypeID\n  * Defaults to UUID version 7\ng  * Can use any supported UUID version","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"KeySmith provides functions to generate UUIDs and TypeIDs. Here are some basic\nexamples:","ref":"readme.html#usage"},{"type":"extras","title":"Generating UUIDs - Overview","doc":"You can generate UUIDs version 4 (random) and version 7 (time-based):\n\n```erlang\n% Generate a UUID v4\n1> keysmith:uuid(v4).\n<<\"79782daf-ff7d-4426-a8f5-e12672e89e32\">>\n\n% Generate a UUID v7\n2> keysmith:uuid(v7).\n<<\"01922919-44d3-779c-84ad-20ab20fc7dbb\">>\n\n% Generate a UUID v7 with a specific timestamp\n3> keysmith:uuid({v7, 1234567890}).\n<<\"00004996-02d2-7bf9-9b68-599f55d37931\">>\n```\n\nUUIDs can be generated in different formats:\n\n```erlang\n4> keysmith:uuid(v4, binary).\n<<193,169,209,27,160,43,73,83,147,64,63,136,127,77,166,39>>\n\n5> keysmith:uuid(v4, hex_nodash).\n<<\"01922919d63d7de990a0209e23b50747\">>\n```","ref":"readme.html#generating-uuids"},{"type":"extras","title":"Generating TypeIDs - Overview","doc":"TypeIDs are a combination of a type prefix and a UUID. They are useful for\ncreating namespaced unique identifiers:\n\n```erlang\n% Generate a TypeID with default UUID v7\n6> keysmith:type_id(user).\n<<\"user_01j8mhm5vafn8vprb7g6dz4q90\">>\n\n% Generate a TypeID with a specific UUID\n7> keysmith:type_id(product, v4).\n<<\"product_7fv003jbwg9ptvecwr68p6n5k6\">>\n```","ref":"readme.html#generating-typeids"},{"type":"extras","title":"Parsing IDs - Overview","doc":"KeySmith can also parse UUIDs and TypeIDs back into their components:\n\n```erlang\n8> UUID = keysmith:uuid(v7).\n<<\"019228d7-b720-7484-ab83-25332e9b0a33\">>\n9> keysmith:parse(uuid, UUID).\n{v7,1727266452545,\n    <<78,9:4>>,\n    <<143,127,240,176,213,200,238,33:6>>}\n\n10> TypeID = keysmith:type_id(order).\n<<\"order_01hm90qbvvgb31sqtrd5zs8cj2\">>\n11> keysmith:parse(type_id, TypeID).\n{order,{v7,1727266470507,\n           <<32,11:4>>,\n           <<133,246,230,190,48,142,227,36:6>>}}\n```\n\nFor more detailed information on available functions and options, please refer\nto the module documentation.","ref":"readme.html#parsing-ids"},{"type":"extras","title":"Changelog - Overview","doc":"See the [Releases](https://github.com/eproxus/keysmith/releases) page.","ref":"readme.html#changelog"},{"type":"extras","title":"Code of Conduct - Overview","doc":"Find this project's code of conduct in\n[Contributor Covenant Code of Conduct](CODE_OF_CONDUCT.md).","ref":"readme.html#code-of-conduct"},{"type":"extras","title":"Contributing - Overview","doc":"First of all, thank you for contributing with your time and energy.\n\nIf you want to request a new feature make sure to\n[open a feature request](https://github.com/eproxus/keysmith/issues/new?template=feature_request.yaml)\nso we can discuss it first.\n\nBug reports and questions are also welcome. If you believe you've found a bug,\nfeel free to [report an issue](https://github.com/eproxus/keysmith/issues/new?template=bug_report.yaml).\n\nIf you have a question, search the discussions and issues since it might have\nalready been answered before. If you can't find an answer, you\ncan [open a new discussion](https://github.com/eproxus/keysmith/discussions/new/choose).\n\nContributions will be subject to the MIT License. You will retain the copyright.\n\nFor more information check out [CONTRIBUTING.md](CONTRIBUTING.md).","ref":"readme.html#contributing"},{"type":"extras","title":"Security - Overview","doc":"This project's security policy is made explicit in [SECURITY.md](SECURITY.md).","ref":"readme.html#security"},{"type":"extras","title":"Conventions - Overview","doc":"","ref":"readme.html#conventions"},{"type":"extras","title":"Versions - Overview","doc":"This project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"readme.html#versions"},{"type":"extras","title":"License - Overview","doc":"This project uses the [MIT License](LICENSE.md).\n\n\n[ci]:     https://github.com/eproxus/keysmith/actions/workflows/erlang.yml\n[ci-img]: https://github.com/eproxus/keysmith/actions/workflows/erlang.yml/badge.svg","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased](https://github.com/eproxus/keysmith/compare/v0.5.0...HEAD)\n\n## [0.5.0](https://github.com/eproxus/keysmith/releases/tag/v0.5.0) - 2024-09-25\n\nInitial public version of the library.","ref":"changelog.html"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n=====================\n\nCopyright © `2024` `Adam Lindberg`\n\nPermission is hereby granted, free of charge, to any person\nobtaining a copy of this software and associated documentation\nfiles (the “Software”), to deal in the Software without\nrestriction, including without limitation the rights to use,\ncopy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the\nSoftware is furnished to do so, subject to the following\nconditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES\nOF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT\nHOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,\nWHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\nFROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR\nOTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, religion, or sexual identity\nand orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the\n  overall community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or\n  advances of any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email\n  address, without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at\n`hello [insert at character here] alind dot io`.\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series\nof actions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or\npermanent ban.","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior,  harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within\nthe community.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.0, available at\n .\n\nCommunity Impact Guidelines were inspired by [Mozilla's code of conduct\nenforcement ladder](https://github.com/mozilla/diversity).\n\n[homepage]:  \n\nFor answers to common questions about this code of conduct, see the FAQ at\n . Translations are available at\n .","ref":"code_of_conduct.html#attribution"},{"type":"extras","title":"Security","doc":"# Security policy\n\nThanks for helping make `keysmith` safer for everyone.\n\nFind below updated information on our security policy.","ref":"security.html"},{"type":"extras","title":"Security - Security","doc":"We take the security of this software seriously.\n\nWe don't implement a bug bounty program or bounty rewards, but will work with\nyou to ensure that your findings get the appropriate handling.","ref":"security.html#security"},{"type":"extras","title":"Reporting security issues - Security","doc":"If you believe you have found a security vulnerability in this repository,\nplease report it to `hello [insert at character here] alind dot io`.\n\nPlease do not report security vulnerabilities through public channels, like\nGitHub issues, discussions, or pull requests.\n\nPlease include as much of the information listed below as you can to help us\nbetter understand and resolve the issue:\n\n- the type of issue (e.g., buffer overflow, SQL injection, or cross-site\n  scripting)\n- full paths of source file(s) related to the manifestation of the issue\n- the location of the affected source code (tag/branch/commit or direct URL)\n- any special configuration required to reproduce the issue\n- step-by-step instructions to reproduce the issue\n- proof-of-concept or exploit code (if possible)\n- impact of the issue, including how an attacker might exploit the issue\n\nThis information will help us triage your report more quickly.","ref":"security.html#reporting-security-issues"},{"type":"extras","title":"Contributing","doc":"# Contributing to `keysmith`\n\n1. [License](#license)\n1. [Reporting a bug](#reporting-a-bug)\n1. [Requesting or implementing a feature](#requesting-or-implementing-a-feature)\n1. [Submitting your changes](#submitting-your-changes)\n   1. [Code style](#code-style)\n   1. [Committing your changes](#committing-your-changes)\n   1. [Pull requests and branching](#pull-requests-and-branching)\n   1. [Credits](#credits)","ref":"contributing.html"},{"type":"extras","title":"License - Contributing","doc":"`keysmith` is licensed under the [MIT License](LICENSE.md), for all code.","ref":"contributing.html#license"},{"type":"extras","title":"Reporting a bug - Contributing","doc":"`keysmith` is not perfect software and will be buggy.\n\nBugs can be reported via\n[GitHub issues: bug report](https://github.com/eproxus/keysmith/issues/new?template=bug_report.md).\n\nSome contributors and maintainers may be unpaid developers working on\n`keysmith`, in their own time, with limited resources. We ask for respect and\nunderstanding, and will provide the same back.\n\nIf your contribution is an actual bug fix, we ask you to include tests that, not\nonly show the issue is solved, but help prevent future regressions related to\nit.","ref":"contributing.html#reporting-a-bug"},{"type":"extras","title":"Requesting or implementing a feature - Contributing","doc":"Before requesting or implementing a new feature, do the following:\n\n- search, in existing [issues](https://github.com/eproxus/keysmith/issues)\n  (open or closed), whether the feature might already be in the works, or has\n  already been rejected,\n- make sure you're using the latest software release (or even the latest code,\n  if you're going for _bleeding edge_).\n\nIf this is done, open up a\n[GitHub issues: feature request](https://github.com/eproxus/keysmith/issues/new?template=feature_request.md).\n\nWe may discuss details with you regarding the implementation, and its inclusion\nwithin the project.\n\nWe try to have as many of `keysmith`'s features tested as possible. Everything\nthat a user can do, and is repeatable in any way, should be tested, to guarantee\nbackwards compatible.","ref":"contributing.html#requesting-or-implementing-a-feature"},{"type":"extras","title":"Submitting your changes - Contributing","doc":"","ref":"contributing.html#submitting-your-changes"},{"type":"extras","title":"Code style - Contributing","doc":"- do not introduce trailing whitespace\n- indentation is 4 spaces, not tabs\n- try not to introduce lines longer than 100 characters\n- write small functions whenever possible, and use descriptive names for\n  functions and variables\n- comment tricky or non-obvious decisions made to explain their rationale","ref":"contributing.html#code-style"},{"type":"extras","title":"Committing your changes - Contributing","doc":"Merging to the `main` branch will usually be preceded by a squash.\n\nWhile it's Ok (and expected) your commit messages relate to why a given change\nwas made, be aware that the final commit (the merge one) will be the issue\ntitle, so it's important it is as specific as possible. This will also help\neventual automated changelog generation.","ref":"contributing.html#committing-your-changes"},{"type":"extras","title":"Pull requests and branching - Contributing","doc":"All fixes to `keysmith` end up requiring a +1 from one or more of the project's\nmaintainers.\n\nDuring the review process, you may be asked to correct or edit a few things\nbefore a final rebase to merge things. Do send edits as individual commits to\nallow for gradual and partial reviews to be done by reviewers.","ref":"contributing.html#pull-requests-and-branching"},{"type":"extras","title":"Credits - Contributing","doc":"`keysmith` has been improved by the following\n[contributors](https://github.com/eproxus/keysmith/graphs/contributors).","ref":"contributing.html#credits"}],"content_type":"text/plain","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}